==> crisis-management-resources-v0.2-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/BusProviderEvent_WSOUIService.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/v3/./busProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	name = "busProviderEvent")
public class BusProviderEvent_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "busProviderEvent");
	public final static QName BusProviderEventPort = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "busProviderEvent");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/v3/busProvider.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/v3/busProvider.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public BusProviderEvent_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "busProviderEventPort")
	public NotificationProducer getBusProviderEventPort() {
	    return super.getPort(BusProviderEventPort, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "busProviderEventPort")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(BusProviderEventPort, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}

==> crisis-management-resources-v0.4-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/BusProviderEvent_WSOUIService.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/management/generated/./busProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	name = "busProviderEvent")
public class BusProviderEvent_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "busProviderEvent");
	public final static QName BusProviderEventPort = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "busProviderEvent");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/management/generated/busProvider.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/management/generated/busProvider.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public BusProviderEvent_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "busProviderEventPort")
	public NotificationProducer getBusProviderEventPort() {
	    return super.getPort(BusProviderEventPort, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "busProviderEventPort")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(BusProviderEventPort, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}
